# -*- coding: utf-8 -*-
"""
Created on Wed Apr  3 11:40:35 2013

@author: jkibele
"""
import sys
from PyQt4.QtGui import QApplication
from benthic_photo_survey.bps_gui import MainWindow

if __name__ == '__main__':
    app = QApplication(sys.argv)
    frame = MainWindow()
    frame.show()
    app.exec_()